@@ -5,6 +5,7 @@ from contextlib import contextmanager
 import curses
 from curses import setupterm, tigetnum, tigetstr, tparm
 from fcntl import ioctl
+import collections
 
 try:
     from io import UnsupportedOperation as IOUnsupportedOperation
@@ -79,7 +80,7 @@ class Terminal(object):
             stream = sys.__stdout__
         try:
             stream_descriptor = (stream.fileno() if hasattr(stream, 'fileno')
-                                 and callable(stream.fileno)
+                                 and isinstance(stream.fileno, collections.Callable)
                                  else None)
         except IOUnsupportedOperation:
             stream_descriptor = None
@@ -89,7 +90,7 @@ class Terminal(object):
         self._does_styling = ((self.is_a_tty or force_styling) and
                               force_styling is not None)
 
-        # The descriptor to direct terminal initialization sequences to.
+        # The desciptor to direct terminal initialization sequences to.
         # sys.__stdout__ seems to always have a descriptor of 1, even if output
         # is redirected.
         self._init_descriptor = (sys.__stdout__.fileno()
@@ -337,9 +338,6 @@ class Terminal(object):
         # don't name it after the underlying capability, because we deviate
         # slightly from its behavior, and we might someday wish to give direct
         # access to it.
-        if not self._does_styling:
-            return 0
-
         colors = tigetnum('colors')  # Returns -1 if no color support, -2 if no
                                      # such cap.
         #  self.__dict__['colors'] = ret  # Cache it. It's not changing.
